//[mahjong-utils](../../../index.md)/[mahjongutils.yaku](../index.md)/[Yaku](index.md)/[han](han.md)

# han

[common]\
val [han](han.md): [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)

番数
